import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { optionsListApi } from '/@/api/tigerapi/wms/wms_item';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';

export const columns: BasicColumn[] = [
  {
    title: '物料代码',
    dataIndex: 'ITEM_CODE',
    width: 200,
    sorter: true,
    resizable:true
  },
  {
    title: '物料描述',
    dataIndex: 'ITEM_NAME',
    width: 200,
    sorter: true,
    resizable:true
  },
  {
    title: '条码',
    dataIndex: 'SN',
    width:300,
    sorter: true,
    resizable:true
  },
  {
    title: '操作时间',
    dataIndex: 'UPDATE_TIME',
    resizable:true
  },
  {
    title: '延期天数',
    dataIndex: 'PostponeDays',
    width:150,
    sorter: true,
    resizable:true
  },
  {
    title: '数量',
    dataIndex: 'QTY',
    sorter: true,
    resizable:true
  },
  {
    title: '储存状态',
    dataIndex: 'STATUS',
    width: 180,
    resizable:true,
    customRender: ({ record }) => {
      const status = record.STATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = '不存在';
          color = 'green';
          break;
        case 10:
          text = '送货中';
          color = 'blue';
          break;
        case 20:
          text = '待检验';
          color = 'green';
          break;
        case 30:
          text = '待入库';
          color = 'blue';
          break;
        case 40:
          text = '在库中';
          color = 'blue';
          break;
        case 50:
          text = '已下架';
          color = 'green';
          break;
        case 60:
          text = '已发料';
          color = 'red';
          break;
        case 70:
          text = '已上料';
          color = 'red';
          break;
        case 80:
          text = '已耗尽';
          color = 'green';
          break;
        case 90:
          text = '已退料';
          color = 'green';
          break;
        case 100:
          text = '已发货';
          color = 'green';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
    sorter: true,
  },
  {
    title: '仓库',
    dataIndex: 'WH_CODE',
    width:100,
    sorter: true,
    resizable:true
  },
  {
    title: '储区',
    dataIndex: 'REGION_CODE',
    sorter: true,
    resizable:true
  },
  {
    title: '货架',
    dataIndex: 'SHELF_CODE',
    sorter: true,
    resizable:true
  },
  {
    title: '储位',
    dataIndex: 'LOCATION_CODE',
    sorter: true,
    resizable:true
  },
  {
    title: '单位',
    dataIndex: 'UNIT',
    resizable:true
  },
  {
    title: '生产日期',
    dataIndex: 'PROD_DATE',
    resizable:true
  },
  {
    title: '首次入库日期',
    dataIndex: 'FIRST_IN_DATE',
    resizable:true
  },
  {
    title: '业务编码',
    dataIndex: 'TRANS_CODE',
    resizable:true
  },
  {
    title: '单据号码',
    dataIndex: 'TRANS_NO',
    resizable:true
  },
  {
    title: '单据行号',
    dataIndex: 'TRANS_LINE',
    width:100,
    resizable:true
  },
  {
    title: '供应商代码',
    dataIndex: 'SUPP_CODE',
    width:100,
    resizable:true
  },
  {
    title: '供应商批次号',
    dataIndex: 'SUPP_LOTNO',
    resizable:true
  },
  {
    title: '批次号',
    dataIndex: 'LOTNO',
    resizable:true
  },
  {
    title: '箱号',
    dataIndex: 'CARTON_NO',
    resizable:true
  },
  {
    title: '栈板号',
    dataIndex: 'PALLET_NO',
    resizable:true
  },
  {
    title: '更新人',
    dataIndex: 'UPDATE_USER',
    resizable:true
  },{
    title: 'ID',
    dataIndex: 'ID',
    ifShow:false,
    resizable:true
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'SN',
    label: '条码',
    component: 'Input',
    colProps: { span: 8 },
  },
 
  {
    field: 'ITEM_CODE',
    label: '物料代码',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'STATUS',
    label: '存储状态',
    component: 'ApiSelect',
    colProps: { span: 8 },
    defaultValue:40,
    componentProps: {
      mode: 'multiple',
      api: optionsListApi,
      resultField: 'Data',
      labelField: 'Desc',
      valueField: 'Value',
    }
  },
  {
    field: 'WH_CODE',
    label: '仓库',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'SHELF_CODE',
    label: '货架',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'LOCATION_CODE',
    label: '储位',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'UPDATE_TIME',
    label: '操作时间',
    component: 'RangePicker',
    ifShow:false,
  },
];
// 延期天数
export const checkStrictlyFormSchema: FormSchema[] = [
  {
    field: 'PostponeDays',
    label: '延期天数',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
    rules: [
      { required: true },
      {
        pattern: /(^[1-9]\d*$)|(^[1-9]\d*[.]{1}[0-9]{1,2}$)|(^0[.]{1}[0-9]{1,2}$)/,
        message: '只能输入正整数，且最多两位小数点',
      },
    ],
  },
 
];
